==> openmetadata-ingestion-1.0.0.0.dev0.tar.gz: openmetadata-ingestion-1.0.0.0.dev0/src/metadata/ingestion/source/pipeline/dagster/connection.py <==
#  Copyright 2021 Collate
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

"""
Source connection handler
"""
from typing import Optional

from dagster_graphql import DagsterGraphQLClient
from gql.transport.requests import RequestsHTTPTransport

from metadata.generated.schema.entity.automations.workflow import (
    Workflow as AutomationWorkflow,
)
from metadata.generated.schema.entity.services.connections.pipeline.dagsterConnection import (
    DagsterConnection,
)
from metadata.ingestion.connections.test_connections import test_connection_steps
from metadata.ingestion.ometa.ometa_api import OpenMetadata
from metadata.ingestion.source.pipeline.dagster.queries import TEST_QUERY_GRAPHQL


def get_connection(connection: DagsterConnection) -> DagsterGraphQLClient:
    """
    Create connection
    """
    url = connection.host
    dagster_connection = DagsterGraphQLClient(
        url,
        transport=RequestsHTTPTransport(
            url=f"{url}/graphql",
            headers={"Dagster-Cloud-Api-Token": connection.token.get_secret_value()}
            if connection.token
            else None,
        ),
    )

    return dagster_connection


def test_connection(
    metadata: OpenMetadata,
    client: DagsterGraphQLClient,
    service_connection: DagsterConnection,
    automation_workflow: Optional[AutomationWorkflow] = None,
) -> None:
    """
    Test connection. This can be executed either as part
    of a metadata workflow or during an Automation Workflow
    """

    def custom_executor_for_pipeline():
        client._execute(TEST_QUERY_GRAPHQL)  # pylint: disable=protected-access

    test_fn = {"GetPipelines": custom_executor_for_pipeline}

    test_connection_steps(
        metadata=metadata,
        test_fn=test_fn,
        service_fqn=service_connection.type.value,
        automation_workflow=automation_workflow,
    )

==> openmetadata-ingestion-1.0.5.0.tar.gz: openmetadata-ingestion-1.0.5.0/src/metadata/ingestion/source/pipeline/dagster/connection.py <==
#  Copyright 2021 Collate
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#  http://www.apache.org/licenses/LICENSE-2.0
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

"""
Source connection handler
"""
from typing import Optional

from dagster_graphql import DagsterGraphQLClient
from gql.transport.requests import RequestsHTTPTransport

from metadata.generated.schema.entity.automations.workflow import (
    Workflow as AutomationWorkflow,
)
from metadata.generated.schema.entity.services.connections.pipeline.dagsterConnection import (
    DagsterConnection,
)
from metadata.ingestion.connections.test_connections import test_connection_steps
from metadata.ingestion.ometa.ometa_api import OpenMetadata
from metadata.ingestion.source.pipeline.dagster.queries import TEST_QUERY_GRAPHQL
from metadata.utils.helpers import clean_uri


def get_connection(connection: DagsterConnection) -> DagsterGraphQLClient:
    """
    Create connection
    """
    url = clean_uri(connection.host)
    dagster_connection = DagsterGraphQLClient(
        url,
        transport=RequestsHTTPTransport(
            url=f"{url}/graphql",
            headers={"Dagster-Cloud-Api-Token": connection.token.get_secret_value()}
            if connection.token
            else None,
            timeout=connection.timeout,
        ),
    )

    return dagster_connection


def test_connection(
    metadata: OpenMetadata,
    client: DagsterGraphQLClient,
    service_connection: DagsterConnection,
    automation_workflow: Optional[AutomationWorkflow] = None,
) -> None:
    """
    Test connection. This can be executed either as part
    of a metadata workflow or during an Automation Workflow
    """

    def custom_executor_for_pipeline():
        client._execute(TEST_QUERY_GRAPHQL)  # pylint: disable=protected-access

    test_fn = {"GetPipelines": custom_executor_for_pipeline}

    test_connection_steps(
        metadata=metadata,
        test_fn=test_fn,
        service_type=service_connection.type.value,
        automation_workflow=automation_workflow,
    )
